@@ -109,7 +109,7 @@ class SketchComponents(object):
             for id_, d in zip(id, description):
                 div_list.append(html.Div(html.P(d, id=prefix_id + id_),
                                     style={'height': '20px', 'width': '900px', 'float': 'left',
-                                                'font-family': 'Open Sans Light'}))
+                                                'font-family': 'open sans'}))
 
         return html.Div(div_list,
             style={'width': str(width) + 'px', 'marginBottom': 0, 'marginTop': 5, 'marginLeft': 5,
@@ -358,7 +358,7 @@ class SketchComponents(object):
 
 
     def table(self, caption=None, id=None, prefix_id='', element_add=None, columns=None, downloadplot_caption=None,
-             downloadplot_tag=None, download_file=None, width=None):
+             downloadplot_tag=None, download_file=None, width=None, font_size=14, font_family='open sans'):
         """
 
         Parameters
@@ -428,9 +428,11 @@ class SketchComponents(object):
                         # data=[{}],
                         #row_selectable='single',
                         # columns=[{"name": [], "id": []}],
-                        filtering=True,
-                        sorting=True,
+                        sort_action="native",
+                        sort_mode="multi",
+                        selected_columns=[],
                         selected_rows=[],
+                        style_cell={'fontSize': font_size, 'font-family': font_family},
                         id=prefix_id + id_
                     )
                 else:
